==> crud-el-0.1.10.tgz: package/src/CrudEl/hooks.ts <==
import { reactive } from 'vue'

// 支持的钩子对象
const hooksName = {
    /**提交之前 */
    beforeSubmitHandler: 'beforeSubmitHandler',

    /** 启用/禁用之前 */
    beforedisabledHandler: 'beforedisabledHandler',
    /** 启用/禁用之后 */
    afterdisabledHandler: 'afterdisabledHandler',

    /** 新增之前 */
    beforeAddHandler: 'beforeAddHandler',
    /** 编辑之前 */
    beforeEditHandler: 'beforeEditHandler',

    /** 查询之前 */
    beforeQueryHandler: 'beforeQueryHandler',
    /** 查询之后 */
    afterQueryHandler: 'afterQueryHandler',

    /** 删除之前 */
    beforeDeteleHandler: 'beforeDeteleHandler',
    /** 删除之后 */
    afterDeteleHandler: 'afterDeteleHandler',

    // 表格懒加载之前
    beforeTableLazyHandler: 'beforeTableLazyHandler'
}

/**
 * 注册钩子
 * @param hooks 组件注册的钩子对象
 * @returns 返回钩子处理函数及钩子名称
 */
function useHooks(hooks: HooksConfigType = { debug: false }) {

    // 当前实例的钩子
    const state: HooksObjectType = reactive({
        hooks: {}
    })

    // 向当前实例注册钩子
    Object.keys(hooks).forEach((item) => {
        if (item !== 'debug') {
            state.hooks[item] = hooks[item]
        }
    })

    /**
     * 处理钩子函数
     * @param hookName 钩子名称
     * @param data 钩子接收的响应式数据
     * @returns 返回处理结果
     */
    const hookHandler = (hookName: string, data: { CrudState: any, Data: any }) => {

        let res = false
        try {
            if (hooks.debug) {
                console.group('DeBug：', hookName)
                console.table(data.Data)
                console.groupEnd()
            }
            // 自定义的返回值是什么
            res = state.hooks[hookName](data)

        } catch (error) {
            res = true
        }
        console.log(`【${hookName}】%c处理结果： `, ` color:red;`, res)
        return res
    }

    return {
        hookHandler
    }
}

export { hooksName, useHooks }

==> crud-el-0.2.1.tgz: package/src/CrudEl/hooks.ts <==
import { reactive } from 'vue'

interface HooksObject {
    [key: string]: any
}
interface HooksConfig {
    debug?: boolean
    [key: string]: any
}



// 支持的钩子对象
const hooksName = {
    /**提交之前 */
    beforeSubmitHandler: 'beforeSubmitHandler',

    /** 启用/禁用之前 */
    beforedisabledHandler: 'beforedisabledHandler',
    /** 启用/禁用之后 */
    afterdisabledHandler: 'afterdisabledHandler',

    /** 新增之前 */
    beforeAddHandler: 'beforeAddHandler',
    /** 编辑之前 */
    beforeEditHandler: 'beforeEditHandler',

    /** 查询之前 */
    beforeQueryHandler: 'beforeQueryHandler',
    /** 查询之后 */
    afterQueryHandler: 'afterQueryHandler',

    /** 删除之前 */
    beforeDeteleHandler: 'beforeDeteleHandler',
    /** 删除之后 */
    afterDeteleHandler: 'afterDeteleHandler',

    // 表格懒加载之前
    beforeTableLazyHandler: 'beforeTableLazyHandler'
}

/**
 * 注册钩子
 * @param hooks 组件注册的钩子对象
 * @returns 返回钩子处理函数及钩子名称
 */
function useHooks(hooks: HooksConfig = { debug: false }) {
    console.log(hooks);


    // 当前实例的钩子
    const state: HooksObject = reactive({
        hooks: {}
    })

    // 向当前实例注册钩子
    Object.keys(hooks).forEach((item) => {
        if (item !== 'debug') {
            state.hooks[item] = hooks[item]
        }
    })

    /**
     * 处理钩子函数
     * @param hookName 钩子名称
     * @param data 钩子接收的响应式数据
     * @returns 返回处理结果
     */
    const hookHandler = (hookName: string, data: { CrudState: any, Data: any }) => {

        let res = false
        try {
            if (hooks.debug) {
                console.group('DeBug：', hookName)
                console.table(data.Data)
                console.groupEnd()
            }
            // 自定义的返回值是什么
            res = state.hooks[hookName](data)

        } catch (error) {
            res = true
        }
        return res
    }

    return {
        hookHandler
    }
}

export { hooksName, useHooks }
